==> monica-3.7.0p0.tgz: www/monica/resources/lang/pt-BR/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Como foi o seu dia? Você pode avaliá-lo uma vez por dia.',
    'journal_come_back' => 'Obrigado. Volte amanhã para avaliar o seu dia novamente.',
    'journal_description' => 'Observação: o diário lista ambos os registros manuais e automáticos, como Atividades feitas com seus contatos. Embora você possa excluir lançamentos do diário manualmente, você terá que excluir a atividade diretamente na página de contato.',
    'journal_add' => 'Adicionar uma entrada no diário',
    'journal_edit' => 'Editar uma entrada no diário',
    'journal_empty' => 'Diário vazio',
    'journal_created_at' => 'Criado em {date}',
    'journal_created_automatically' => 'Criar automaticamente',
    'journal_entry_type_journal' => 'Entrada do diário',
    'journal_entry_type_activity' => 'Atividade',
    'journal_entry_rate' => 'Você avaliou seu dia.',
    'journal_add_comment' => 'Deseja adicionar um comentário (opcional)?',
    'journal_show_comment' => 'Mostrar comentário',
    'entry_delete_success' => 'A informação do diário foi excluída com sucesso.',
    'journal_add_title' => 'Título (opcional)',
    'journal_add_date' => 'Encontro',
    'journal_add_post' => 'Texto',
    'journal_add_cta' => 'Salvar',
    'journal_blank_cta' => 'Adicione sua primeira informação no diário',
    'journal_blank_description' => 'O diário permite que você escreva eventos que aconteceram com você para que lembre-se deles.',
    'delete_confirmation' => 'Tem certeza que deseja excluir este registro do diário?',
];

==> monica-4.1.2p0.tgz: www/monica/resources/lang/pt-BR/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Como foi o seu dia? Você pode avaliá-lo uma vez por dia.',
    'journal_come_back' => 'Obrigado. Volte amanhã para avaliar o seu dia novamente.',
    'journal_description' => 'Observação: o diário lista ambos os registros manuais e automáticos, como Atividades feitas com seus contatos. Embora você possa excluir lançamentos do diário manualmente, você terá que excluir a atividade diretamente na página de contato.',
    'journal_add' => 'Adicionar uma entrada no diário',
    'journal_edit' => 'Editar uma entrada no diário',
    'journal_empty' => 'Diário vazio',
    'journal_created_at' => 'Criado em {date}',
    'journal_created_automatically' => 'Criar automaticamente',
    'journal_entry_type_journal' => 'Entrada do diário',
    'journal_entry_type_activity' => 'Atividade',
    'journal_entry_rate' => 'Você avaliou seu dia.',
    'journal_add_comment' => 'Deseja adicionar um comentário (opcional)?',
    'journal_show_comment' => 'Mostrar comentário',
    'entry_delete_success' => 'A informação do diário foi excluída com sucesso.',
    'journal_add_title' => 'Título (opcional)',
    'journal_add_date' => 'Encontro',
    'journal_add_post' => 'Texto',
    'journal_add_cta' => 'Salvar',
    'journal_blank_cta' => 'Adicione sua primeira informação no diário',
    'journal_blank_description' => 'O diário permite que você escreva eventos que aconteceram com você para que lembre-se deles.',
    'delete_confirmation' => 'Tem certeza que deseja excluir este registro do diário?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
